@@ -21,9 +21,18 @@ def deploy(c):
     subprocess.run("cdk deploy --require-approval never", check=True, shell=True, cwd=demo_app_dir)
 
 
-@task
-def generate_open_api_spec(c):
-    path = Path(__file__).parent.joinpath("demo_app/demo_app")
-    schema, *_ = gen_open_api_inspect(path)
-    with path.joinpath("open_api_spec.json").open("w") as f:
+@task(help={"app_dir": "The app directory", "output_file_path": "The output directory"})
+def generate_open_api_spec(c, app_dir, output_file_path):
+    """
+    Generate an open api spec and write to file
+    """
+    app_dir_path = Path(app_dir)
+    app_dir_path.exists()
+
+    schema, *_ = gen_open_api_inspect(app_dir_path)
+
+    output_file_path = Path(output_file_path)
+    output_file_path.parent.exists()
+
+    with output_file_path.open("w") as f:
         json.dump(schema, f, indent=4)
